@@ -127,13 +127,20 @@ SYMBOL_EDIT_FRAME::SYMBOL_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
     LoadSettings( m_settings );
 
     m_libMgr = new SYMBOL_LIBRARY_MANAGER( *this );
+    bool loadingCancelled = false;
 
-    // Preload libraries before using SyncLibraries the first time, as the preload is threaded
-    WX_PROGRESS_REPORTER reporter( this, _( "Loading Symbol Libraries" ),
-                                   m_libMgr->GetLibraryCount(), true );
-    m_libMgr->Preload( reporter );
+    {
+        // Preload libraries before using SyncLibraries the first time, as the preload is
+        // multi-threaded
+        WX_PROGRESS_REPORTER reporter( this, _( "Loading Symbol Libraries" ),
+                                       m_libMgr->GetLibraryCount(), true );
+        m_libMgr->Preload( reporter );
 
-    SyncLibraries( false );
+        loadingCancelled = reporter.IsCancelled();
+        wxSafeYield();
+    }
+
+    SyncLibraries( false, loadingCancelled );
     m_treePane = new SYMBOL_TREE_PANE( this, m_libMgr );
 
     resolveCanvasType();
@@ -168,28 +175,28 @@ SYMBOL_EDIT_FRAME::SYMBOL_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
     m_auimgr.SetManagedWindow( this );
 
     CreateInfoBar();
-    m_auimgr.AddPane( m_mainToolBar, EDA_PANE().HToolbar().Name( "MainToolbar" )
+    m_auimgr.AddPane( m_mainToolBar, EDA_PANE().HToolbar().Name( wxT( "MainToolbar" ) )
                       .Top().Layer( 6 ) );
-    m_auimgr.AddPane( m_messagePanel, EDA_PANE().Messages().Name( "MsgPanel" )
+    m_auimgr.AddPane( m_messagePanel, EDA_PANE().Messages().Name( wxT( "MsgPanel" ) )
                       .Bottom().Layer( 6 ) );
 
-    m_auimgr.AddPane( m_optionsToolBar, EDA_PANE().VToolbar().Name( "OptToolbar" )
+    m_auimgr.AddPane( m_optionsToolBar, EDA_PANE().VToolbar().Name( wxT( "OptToolbar" ) )
                       .Left().Layer( 3 ) );
-    m_auimgr.AddPane( m_treePane, EDA_PANE().Palette().Name( "SymbolTree" )
+    m_auimgr.AddPane( m_treePane, EDA_PANE().Palette().Name( wxT( "SymbolTree" ) )
                       .Left().Layer( 2 )
                       .Caption( _( "Libraries" ) )
                       .MinSize( 250, -1 ).BestSize( 250, -1 ) );
-    m_auimgr.AddPane( m_drawToolBar, EDA_PANE().VToolbar().Name( "ToolsToolbar" )
+    m_auimgr.AddPane( m_drawToolBar, EDA_PANE().VToolbar().Name( wxT( "ToolsToolbar" ) )
                       .Right().Layer( 2 ) );
 
-    m_auimgr.AddPane( GetCanvas(), wxAuiPaneInfo().Name( "DrawFrame" )
+    m_auimgr.AddPane( GetCanvas(), wxAuiPaneInfo().Name( wxT( "DrawFrame" ) )
                       .CentrePane() );
 
     FinishAUIInitialization();
 
     if( m_settings->m_LibWidth > 0 )
     {
-        wxAuiPaneInfo& treePane = m_auimgr.GetPane( "SymbolTree" );
+        wxAuiPaneInfo& treePane = m_auimgr.GetPane( wxT( "SymbolTree" ) );
 
         // wxAUI hack: force width by setting MinSize() and then Fixed()
         // thanks to ZenJu http://trac.wxwidgets.org/ticket/13180
@@ -235,6 +242,9 @@ SYMBOL_EDIT_FRAME::SYMBOL_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
 
     // Ensure the window is on top
     Raise();
+
+    if( loadingCancelled )
+        ShowInfoBarWarning( _( "Symbol library loading was cancelled by user." ) );
 }
 
 
@@ -265,7 +275,7 @@ SYMBOL_EDIT_FRAME::~SYMBOL_EDIT_FRAME()
 
 void SYMBOL_EDIT_FRAME::LoadSettings( APP_SETTINGS_BASE* aCfg )
 {
-    wxCHECK_RET( m_settings, "Call to SYMBOL_EDIT_FRAME::LoadSettings with null m_boardAdapter" );
+    wxCHECK_RET( m_settings, wxT( "Call to SYMBOL_EDIT_FRAME::LoadSettings with null m_boardAdapter" ) );
 
     SCH_BASE_FRAME::LoadSettings( GetSettings() );
 
@@ -280,7 +290,7 @@ void SYMBOL_EDIT_FRAME::LoadSettings( APP_SETTINGS_BASE* aCfg )
 
 void SYMBOL_EDIT_FRAME::SaveSettings( APP_SETTINGS_BASE* aCfg )
 {
-    wxCHECK_RET( m_settings, "Call to SYMBOL_EDIT_FRAME::LoadSettings with null m_boardAdapter" );
+    wxCHECK_RET( m_settings, wxT( "Call to SYMBOL_EDIT_FRAME::LoadSettings with null m_boardAdapter" ) );
 
     GetGalDisplayOptions().m_axesEnabled = true;
 
@@ -502,41 +512,57 @@ void SYMBOL_EDIT_FRAME::setupUIConditions()
 }
 
 
-bool SYMBOL_EDIT_FRAME::canCloseWindow( wxCloseEvent& aEvent )
+bool SYMBOL_EDIT_FRAME::CanCloseSymbolFromSchematic( bool doClose )
 {
-    // Shutdown blocks must be determined and vetoed as early as possible
-    if( KIPLATFORM::APP::SupportsShutdownBlockReason() && aEvent.GetId() == wxEVT_QUERY_END_SESSION
-            && IsContentModified() )
-    {
-        return false;
-    }
-
-    if( m_isSymbolFromSchematic && IsContentModified() )
+    if( IsContentModified() )
     {
         SCH_EDIT_FRAME* schframe = (SCH_EDIT_FRAME*) Kiway().Player( FRAME_SCH, false );
+        wxString        msg = _( "Save changes to '%s' before closing?" );
 
-        switch( UnsavedChangesDialog( this,
-                                      _( "Save changes to schematic before closing?" ),
-                                      nullptr ) )
+        switch( UnsavedChangesDialog( this, wxString::Format( msg, m_reference ), nullptr ) )
         {
         case wxID_YES:
             if( schframe && GetCurSymbol() )  // Should be always the case
                 schframe->SaveSymbolToSchematic( *GetCurSymbol(), m_schematicSymbolUUID );
 
-            return true;
+            break;
 
-        case wxID_NO: return true;
+        case wxID_NO:
+            break;
 
         default:
-        case wxID_CANCEL: return false;
+        case wxID_CANCEL:
+            return false;
         }
     }
 
-    if( !saveAllLibraries( true ) )
+    if( doClose )
+    {
+        GetInfoBar()->ShowMessageFor( wxEmptyString, 1 );
+        SetCurSymbol( nullptr, false );
+        updateTitle();
+    }
+
+    return true;
+}
+
+
+bool SYMBOL_EDIT_FRAME::canCloseWindow( wxCloseEvent& aEvent )
+{
+    // Shutdown blocks must be determined and vetoed as early as possible
+    if( KIPLATFORM::APP::SupportsShutdownBlockReason()
+            && aEvent.GetId() == wxEVT_QUERY_END_SESSION
+            && IsContentModified() )
     {
         return false;
     }
 
+    if( m_isSymbolFromSchematic && !CanCloseSymbolFromSchematic( false ) )
+        return false;
+
+    if( !saveAllLibraries( true ) )
+        return false;
+
     return true;
 }
 
@@ -791,7 +817,7 @@ void SYMBOL_EDIT_FRAME::OnModify()
 
     m_treePane->GetLibTree()->RefreshLibTree();
 
-    if( !GetTitle().StartsWith( "*" ) )
+    if( !GetTitle().StartsWith( wxT( "*" ) ) )
         updateTitle();
 }
 
@@ -906,7 +932,8 @@ wxString SYMBOL_EDIT_FRAME::getTargetLib() const
 }
 
 
-void SYMBOL_EDIT_FRAME::SyncLibraries( bool aShowProgress, const wxString& aForceRefresh )
+void SYMBOL_EDIT_FRAME::SyncLibraries( bool aShowProgress, bool aPreloadCancelled,
+                                       const wxString& aForceRefresh )
 {
     LIB_ID selected;
 
@@ -925,7 +952,7 @@ void SYMBOL_EDIT_FRAME::SyncLibraries( bool aShowProgress, const wxString& aForc
                                                                     libName ) );
                 } );
     }
-    else
+    else if( !aPreloadCancelled )
     {
         m_libMgr->Sync( aForceRefresh,
                 [&]( int progress, int max, const wxString& libName )
@@ -952,7 +979,7 @@ void SYMBOL_EDIT_FRAME::SyncLibraries( bool aShowProgress, const wxString& aForc
         // Try to select the parent library, in case the symbol is not found
         if( !found && selected.IsValid() )
         {
-            selected.SetLibItemName( "" );
+            selected.SetLibItemName( wxEmptyString );
             found = m_libMgr->GetAdapter()->FindItem( selected );
 
             if( found )
@@ -1359,7 +1386,7 @@ bool SYMBOL_EDIT_FRAME::addLibTableEntry( const wxString& aLibFile, TABLE_SCOPE
 
         while( libTable->HasLibrary( libNickname ) )
         {
-            tmp.Printf( "%s%d", fn.GetName(), suffix );
+            tmp.Printf( wxT( "%s%d" ), fn.GetName(), suffix );
             libNickname = tmp;
             suffix += 1;
         }
@@ -1433,7 +1460,7 @@ bool SYMBOL_EDIT_FRAME::replaceLibTableEntry( const wxString& aLibNickname,
     wxString normalizedPath = NormalizePath( aLibFile, &envVars, projectPath );
 
     row->SetFullURI( normalizedPath );
-    row->SetType( "KiCad" );
+    row->SetType( wxT( "KiCad" ) );
 
     try
     {
